@@ -1,4 +1,4 @@
-package Net::Connector::Hillstone::Srx;
+package Net::Connector::Hillstone::Firewall;
 
 #------------------------------------------------------------------------------
 # 加载扩展模块
